unit Solver;

interface

uses Basis,Differences;

function  Solve :TVector;
procedure WriteToDerive(filename :String; const A :TVector);
function  Delta(const A :TVector) :Float;

implementation

uses SysUtils;

function Walkthrow(a,b,c,f :TVector; k1,k2,m1,m2 :Float) :TVector;
var
  alfa,beta :TVector;
  z :Float;
  k :Integer;
begin
  alfa[0] := k1;
  beta[0] := m1;
  for k := 0 to n-1 do begin
    z := b[k] + c[k]*alfa[k];
    alfa[k+1] := -a[k]/z;
    beta[k+1] := (f[k]-c[k]*beta[k])/z;
  end;
  Result[n] := (k2*beta[n]+m2)/(1-k2*alfa[n]);
  for k := n downto 1 do begin
    Result[k-1] := alfa[k]*Result[k] + beta[k];
  end;
end;

function Solve :TVector;
var
  a,b,c,d :TVector;
  k1,k2,m1,m2 :Float;
  i :Integer;
begin
  for i := 0 to n do begin
    a[i] := Int(k,x(i),h);
    c[i] := Int(k,x(i-1),h);
    d[i] := -sqr(h)*Int(f,x(i-1/2),h);
    b[i] := -(sqr(h)*Int(q,x(i-1/2),h) + a[i] + c[i]);
  end;
  k1 := 0;
  m1 := mu1(0);
  k2 := 0;
  m2 := mu2(0);
  Result := Walkthrow(a,b,c,d,k1,k2,m1,m2);
end;

procedure WriteToDerive(filename :String; const A :TVector);
var
  i :Integer;
  f :TextFile;
begin
  AssignFile(f,filename);
  Rewrite(f);
  write(f,'[');
  for i := 0 to n-1 do begin
    writeln(f,'[',FToS(x(i)),',',FToS(A[i]),'],~');
  end;
  writeln(f,'[',FToS(x(n)),',',FToS(A[n]),']]');
  CloseFile(f);
end;

function  Delta(const A :TVector) :Float;
var
  z :Float;
  i :Integer;
begin
  Result := 0;
  for i := 0 to n do begin
    z := abs(A[i]-Exact(i));
    if Result<z then Result := z;
  end;
end;

end.
